-
ANFIS-Design
Function Approximation with ANFIS
- 2014-10-24 05:35:33下载
- 积分:1
-
YC
说明: 遗传算法,一个不错的程序,可以试试看,改进了一点点,大学共同探讨 了(Genetic algorithm (ga), a good program, can try to improve a little bit, the university is discussed
)
- 2013-10-05 18:09:53下载
- 积分:1
-
task1
调用函数,并对函数进行求解,把数据存储,并画出其中几条图(Call the function, and the function is solved, the data is stored, and draw the diagram in which several)
- 2013-05-25 15:44:31下载
- 积分:1
-
least-square-solution
本文借助于矩阵对的标准相关分解(CCD)技术,给出了问题P的通解表示 并且得到了矩阵方程有解的一个充要条件.
(THE LEAST-SQUARE SOLUTIONS OF A MATRIX EQUATION
)
- 2012-05-10 10:46:14下载
- 积分:1
-
duofenbianlv
多分辨率融合的综述文章值得一看 多分辨率融合的综述文章值得一看 (Summary of multi-resolution integration article to see a synthesis of multi-resolution fusion article worth a visit)
- 2007-07-27 13:31:34下载
- 积分:1
-
fuhe12110--o
一个MATLAB报告,是电力系统负荷预测方面的(Report of a communication theory, written in great detail, is what MATLAB side)
- 2010-06-07 21:31:31下载
- 积分:1
-
Mercurial_The_Definitive_Guide
mercurial 分布式版本控制软件指南,方便个人和工程使用,使用方便(mercurial distributed version control software)
- 2013-08-11 17:33:24下载
- 积分:1
-
matlab
matlab中编写计算器程序,matlab中编写计算器程序(matlab calculator in the preparation of procedures, matlab calculator in the preparation of procedures)
- 2009-01-18 18:44:01下载
- 积分:1
-
DateConvert
DateConvert:简单而快速的日期转换
DateConvert转换DATESTR(0)格式的日期向量或序列号和日期向后。
Matlab的DATENUM,DATEVEC和DATESTR接受各种不同意见,但结果他们是缓慢的。如果输入格式正是众所周知,转换可以更快:
DATENUM( 17 - 10 - 2009 11时08分23秒 ):2.97秒
DateConvert( 17 - 10 - 2009 11时08分23秒 , 号码 ):0.039秒
=>“1.3%(1000环,1.5GHz的奔腾- M的,利用Matlab 7.7)
DateConvert不*不*验证作为Matlab的日期函数输入日期:
DATEVEC( 32 - 2 - 2008 25:62:63 )的答复[2008 3 4 2 2 7]
DateConvert( 32 - 2 - 2008 25:61:67 , 载体 )的答复[2008 2 32 25 61 67]!
因此DateConvert几乎微不足道,但对速度进行了优化。我需要时间排序200 000邮票,并从217个减少到11秒的时间。
请运行单元测试TestDateVec检查的有效性和速度。
测试:利用Matlab 6.5,7.7,7.8,winxp的,32位。
纯Matlab代码,所以兼容性的MacOS,Linux操作系统,64位预期。
英语月份名称是必要的。(DateConvert: Simple but fast date conversion
DateConvert converts the DATESTR(0) format to a date vector or serial date number and backwards.
Matlab s DATENUM, DATEVEC and DATESTR accept a variety of inputs, but in consequence they are slow. If the input format is exactly known, the conversion can be much faster:
DATENUM( 17-Oct-2009 11:08:23 ): 2.97 sec
DateConvert( 17-Oct-2009 11:08:23 , number ): 0.039 sec
=> 1.3 (1000 loops, 1.5GHz Pentium-M, Matlab 7.7)
DateConvert does*not* validate the input date as Matlab s date functions:
DATEVEC( 32-Feb-2008 25:62:63 ) replies [2008 3 4 2 2 7],
DateConvert( 32-Feb-2008 25:61:67 , vector ) replies [2008 2 32 25 61 67] !
So DateConvert is nearly trivial, but optimized for speed. I needed it for sorting 200 000 time stamps and reduced the time from 217 to 11 sec.
Please run the unit-test TestDateVec to check validity and speed.
Tested: Matlab 6.5, 7.7, 7.8, WinXP, 32bit.
Pure Matlab code, so compat)
- 2010-07-05 11:59:46下载
- 积分:1
-
qgriddata
These files are for cfd
- 2010-12-09 15:57:11下载
- 积分:1